xpecgen
=========

xpecgen is a python package to calculate x-ray spectra generated in tungsten anodes using the model of `Med. Phys. 43, 4655 <http://dx.doi.org/10.1118/1.4955120>`_. It includes a Graphical User Interface and allows calculation of half-value-layers, norms, and attenuation. It can also export the calculations in XLSX and CSV formats.

For more information check the `GitHub repository <https://github.com/Dih5/xpecgen>`_.
